@@ -91,9 +91,9 @@ class Model:
         # set of containers
         self.mdl.C = pe.Set(dimen=1)
         # current clustering solution
-        sol_u_d = dict(
+        sol_u_d = {
             ((j, i), u[i][j]) for i, j in prod(range(len(u)), range(len(u[0])))
-        )
+        }
         self.mdl.sol_u = pe.Param(self.mdl.C, self.mdl.C,
                                   initialize=sol_u_d, mutable=True)
 
@@ -104,9 +104,9 @@ class Model:
             # set of clusters
             self.mdl.K = pe.Set(dimen=1)
             # distances
-            w_d = dict(
+            w_d = {
                 ((j, i), w[i][j]) for i, j in prod(range(len(w)), range(len(w[0])))
-            )
+            }
             self.mdl.w = pe.Param(self.mdl.C, self.mdl.C,
                                   initialize=w_d, mutable=True)
         # placement case
@@ -126,15 +126,15 @@ class Model:
             # containers usage
             self.mdl.cons = pe.Param(self.mdl.Ccons, self.mdl.T)
             # dv matrix for distance placement
-            dv_d = dict(
+            dv_d = {
                 ((j, i), dv[i][j]) for i, j in prod(range(len(dv)), range(len(dv[0])))
-            )
+            }
             self.mdl.dv = pe.Param(
                 self.mdl.C, self.mdl.C, initialize=dv_d, mutable=True)
             # current placement solution
-            sol_v_d = dict(
+            sol_v_d = {
                 ((j, i), v[i][j]) for i, j in prod(range(len(v)), range(len(v[0])))
-            )
+            }
             self.mdl.sol_v = pe.Param(self.mdl.C, self.mdl.C,
                                       initialize=sol_v_d, mutable=True)
 
@@ -453,8 +453,9 @@ def fill_dual_values(my_mdl: Model) -> Dict:
     return dual_values
 
 
-def get_conflict_graph(my_mdl: Model, constraints_dual_values: Dict, tol: float
-    ) -> nx.Graph:
+def get_conflict_graph(
+    my_mdl: Model, constraints_dual_values: Dict, tol: float
+) -> nx.Graph:
     """Build conflict graph from comapring dual variables."""
     conflict_graph = nx.Graph()
     if my_mdl.pb_number == 1:
